@@ -3,6 +3,9 @@
 """
 Python function to register |UDM| extensions in |LDAP|.
 """
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -1104,7 +1107,7 @@ class UniventionUDMModule(UniventionUDMExtension):
 			try:
 				self.target_udm_module = module_name = mod.module
 			except AttributeError:
-				print("ERROR: python variable 'module' undefined in given file:", filename)
+				print("ERROR: Python variable 'module' undefined in given file:", filename)
 				sys.exit(1)
 		finally:
 			sys.dont_write_bytecode = saved_value
