@@ -1,6 +1,9 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2020-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -35,7 +38,7 @@ import pytest
 
 
 def pytest_addoption(parser):
-	parser.addoption("--installed-lib", action="store_true", help="Test against installed python lib installation (not src)")
+	parser.addoption("--installed-lib", action="store_true", help="Test against installed Python lib installation (not src)")
 
 
 def import_lib_module(name):
