@@ -1,6 +1,9 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2020-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -125,3 +128,9 @@ class TestTranslation(object):
 			assert translation._translation is not None
 		else:
 			assert translation._translation is None
+
+	def test_set_all_language(self):
+		translation = i18n.Translation("univention-lib-unittest", localedir=dirname(__file__))
+		translation.set_language('en_US')
+		i18n.Translation.set_all_languages('de_DE')
+		assert str(translation.locale) == 'de_DE.UTF-8'
